@@ -42,7 +42,8 @@ sparse_table_helper_handler(netsnmp_mib_handler *handler,
                             netsnmp_agent_request_info *reqinfo,
                             netsnmp_request_info *requests);
 
-/** @defgroup table table: Helps you implement a table.
+/** @defgroup table table
+ *  Helps you implement a table.
  *  @ingroup handler
  *
  *  This handler helps you implement a table by doing some of the
@@ -301,7 +302,7 @@ table_helper_handler(netsnmp_mib_handler *handler,
                              var->name, tmp_len) > 0) {
             if (reqinfo->mode == MODE_GETNEXT) {
                 if (var->name != var->name_loc)
-                    free(var->name);
+                    SNMP_FREE(var->name);
                 snmp_set_var_objid(var, reginfo->rootoid,
                                    reginfo->rootoid_len);
             } else {
@@ -679,8 +680,7 @@ sparse_table_helper_handler(netsnmp_mib_handler *handler,
             if ((request->requestvb->type == ASN_NULL && request->processed) ||
                 request->delegated)
                 continue;
-            if (request->requestvb->type == ASN_NULL ||
-                request->requestvb->type == SNMP_NOSUCHINSTANCE) {
+            if (request->requestvb->type == SNMP_NOSUCHINSTANCE) {
                 /*
                  * get next skipped this value for this column, we
                  * need to keep searching forward 
@@ -708,6 +708,10 @@ sparse_table_helper_handler(netsnmp_mib_handler *handler,
                     request->requestvb->type = ASN_PRIV_RETRY;
                 }
                 else {
+                    /*
+                     * If we don't have column info, reset to null so
+                     * the agent will move on to the next table.
+                     */
                     request->requestvb->type = ASN_NULL;
                 }
             }
