@@ -86,6 +86,15 @@ struct mnttab  *HRFS_entry = &HRFS_entry_struct;
 #define	HRFS_type	mnt_fstype
 #define	HRFS_statfs	statvfs
 
+#elif defined(HAVE_STATVFS) && defined(__NetBSD__)
+
+static struct statvfs	*fsstats = NULL;
+struct statvfs		*HRFS_entry;
+static int		fscount;
+#define HRFS_mount	f_mntonname
+#define	HRFS_name	f_mntfromname
+#define HRFS_statfs	statvfs
+#define	HRFS_type	f_fstypename
 #elif defined(HAVE_GETFSSTAT)
 static struct statfs *fsstats = 0;
 static int      fscount;
@@ -452,7 +461,9 @@ var_hrfilesys(struct variable *vp,
         return (u_char *) fsys_type_id;
 
     case HRFSYS_ACCESS:
-#if HAVE_GETFSSTAT
+#if defined(HAVE_STATVFS) && defined(__NetBSD__)
+	long_return = HRFS_entry->f_flag & MNT_RDONLY ? 2 : 1;
+#elif defined(HAVE_GETFSSTAT)
         long_return = HRFS_entry->f_flags & MNT_RDONLY ? 2 : 1;
 #elif defined(cygwin)
         long_return = 1;
@@ -500,12 +511,20 @@ void
 Init_HR_FileSys(void)
 {
 #if HAVE_GETFSSTAT
+#if defined(HAVE_STATVFS) && defined(__NetBSD__)
+    fscount = getvfsstat(NULL, 0, ST_NOWAIT);
+#else
     fscount = getfsstat(NULL, 0, MNT_NOWAIT);
+#endif
     if (fsstats)
         free((char *) fsstats);
     fsstats = NULL;
     fsstats = malloc(fscount * sizeof(*fsstats));
+#if defined(HAVE_STATVFS) && defined(__NetBSD__)
+    getvfsstat(fsstats, fscount * sizeof(*fsstats), ST_NOWAIT);
+#else
     getfsstat(fsstats, fscount * sizeof(*fsstats), MNT_NOWAIT);
+#endif
     HRFS_index = 0;
 #else
     HRFS_index = 1;
@@ -558,28 +577,6 @@ Get_Next_HR_FileSys(void)
     return ++HRFS_index;
 #else
     const char    **cpp;
-    /*
-     * XXX - According to RFC 1514, hrFSIndex must
-     *   "remain constant at least from one re-initialization
-     *    of the agent to the next re-initialization."
-     *
-     *  This simple-minded counter doesn't handle filesystems
-     *    being un-mounted and re-mounted.
-     *  Options for fixing this include:
-     *       - keeping a history of previous indices used
-     *       - calculating the index from filesystem
-     *              specific information
-     *
-     *  Note: this index is also used as hrStorageIndex
-     *     which is assumed to be less than HRS_TYPE_FS_MAX
-     *     This assumption may well be broken if the second
-     *     option above is followed.  Consider indexing the
-     *     non-filesystem-based storage entries first in this
-     *     case, and assume hrStorageIndex > HRS_TYPE_FS_MIN
-     *     (for file-system based storage entries)
-     *
-     *  But at least this gets us started.
-     */
 
     if (fp == NULL)
         return -1;
@@ -597,6 +594,18 @@ Get_Next_HR_FileSys(void)
         if (!strcmp(HRFS_entry->HRFS_type, *cpp))
             return Get_Next_HR_FileSys();
 
+    /*
+     * Try and ensure that index values are persistent
+     *   at least within a single run of the agent
+     */
+    HRFS_index = se_find_value_in_slist("filesys", HRFS_entry->HRFS_name );
+    if (HRFS_index == SE_DNE) {
+        HRFS_index = se_find_free_value_in_slist("filesys");
+        if (HRFS_index == SE_DNE) { HRFS_index = 1; }
+        se_add_pair_to_slist( "filesys",
+                              strdup( HRFS_entry->HRFS_name ), HRFS_index);
+    }
+
     return HRFS_index++;
 #endif                          /* HAVE_GETFSSTAT */
 }
@@ -793,10 +802,14 @@ Get_FSSize(char *dev)
   		 * in case of 512 (f_blocks/2) is returned
   		 * otherwise (f_blocks*(f_bsize/1024)) is returned
   		 */
+#if defined(solaris2) && defined(STRUCT_STATVFS_HAS_F_FRSIZE)
+                return (statfs_buf.f_blocks*(statfs_buf.f_frsize/1024));
+#else
   		if (statfs_buf.f_bsize == 512)
   		    return (statfs_buf.f_blocks/2);
                 else
   		    return (statfs_buf.f_blocks*(statfs_buf.f_bsize/1024));
+#endif
             else
                 return -1;
         }
