@@ -1,7 +1,7 @@
 /*
  *  Interface MIB architecture support
  *
- * $Id: interface_linux.c,v 1.20.2.4 2005/06/15 21:39:50 rstory Exp $
+ * $Id: interface_linux.c,v 1.20.2.8 2006/04/25 17:36:04 hardaker Exp $
  */
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
@@ -23,9 +23,11 @@
 #include <sys/types.h>
 
 #ifdef HAVE_LINUX_ETHTOOL_H
-#   ifdef HAVE_PCI_PCI_H
-#      include <pci/pci.h> /* for u32 typedef in linux/ethtool */
-#   endif /* HAVE_PCI_PCI_H */
+#include <sys/types.h>
+typedef unsigned long long u64;         /* hack, so we may include kernel's ethtool.h */
+typedef __uint32_t u32;         /* ditto */
+typedef __uint16_t u16;         /* ditto */
+typedef __uint8_t u8;           /* ditto */
 #include <linux/ethtool.h>
 #endif /* HAVE_LINUX_ETHTOOL_H */
 #include <linux/sockios.h>
@@ -260,6 +262,11 @@ netsnmp_arch_interface_container_load(netsnmp_container* container,
          * xxx-rks: get descr by linking mem from /proc/pci and /proc/iomem
          */
 
+        /*
+         * subtract out multicast packets from rec_pkt before
+         * we store it as unicast counter.
+         */
+        rec_pkt -= rec_mcast;
 
         entry->stats.ibytes.low = rec_oct & 0xffffffff;
         entry->stats.iucast.low = rec_pkt & 0xffffffff;
@@ -355,6 +362,18 @@ netsnmp_arch_interface_container_load(netsnmp_container* container,
             entry->os_flags &= ~IFF_RUNNING;
         }
 
+        /*
+         * check for promiscuous mode.
+         *  NOTE: there are 2 ways to set promiscuous mode in Linux
+         *  (kernels later than 2.2.something) - using ioctls and
+         *  using setsockopt. The ioctl method tested here does not
+         *  detect if an interface was set using setsockopt. google
+         *  on IFF_PROMISC and linux to see lots of arguments about it.
+         */
+        if(entry->os_flags & IFF_PROMISC) {
+            entry->promiscuous = 1; /* boolean */
+        }
+
         netsnmp_access_interface_entry_overrides(entry);
 
         /*
