@@ -1,7 +1,7 @@
 /*
  *  Interface MIB architecture support
  *
- * $Id: ipaddress_ioctl.c,v 1.8 2004/10/19 03:23:01 rstory Exp $
+ * $Id: ipaddress_ioctl.c,v 1.8.2.1 2005/02/09 21:02:14 nba Exp $
  */
 #include <net-snmp/net-snmp-config.h>
 #include <net-snmp/net-snmp-includes.h>
@@ -299,7 +299,7 @@ _netsnmp_ioctl_ipaddress_container_load_v4(netsnmp_container *container,
  * find unused alias number
  */
 static int
-_next_alias(char *if_name)
+_next_alias(const char *if_name)
 {
     int             i, j, k, sd, interfaces = 0, len;
     struct ifconf   ifc;
@@ -400,7 +400,7 @@ _netsnmp_ioctl_ipaddress_set_v4(netsnmp_ipaddress_entry * entry)
     memset(&ifrq, 0, sizeof(ifrq));
 
     if ('\0' == extras->name[0]) {
-        char *name = netsnmp_access_interface_name_find(entry->if_index);
+        const char *name = netsnmp_access_interface_name_find(entry->if_index);
         int   alias_idx;
 
         if (NULL == name) {
