@@ -57,7 +57,7 @@
 #endif
 
 #if TIME_WITH_SYS_TIME
-# ifdef WIN32
+# if defined (WIN32) || defined (cygwin)
 #  include <sys/timeb.h>
 # else
 # include <sys/time.h>
@@ -85,6 +85,9 @@
 #if HAVE_NET_IF_H
 #include <net/if.h>
 #endif
+#if HAVE_NETINET_IN_VAR_H
+#include <netinet/in_var.h>
+#endif
 #if HAVE_NET_IF_VAR_H
 #include <net/if_var.h>
 #endif
@@ -167,7 +170,6 @@
 #endif                          /* hpux */
 
 #ifdef cygwin
-#define WIN32
 #include <windows.h>
 #endif
 
@@ -223,7 +225,7 @@ struct variable3 interfaces_variables[] = {
     {IFMTU, ASN_INTEGER, RONLY, var_ifEntry, 3, {2, 1, 4}},
     {IFSPEED, ASN_GAUGE, RONLY, var_ifEntry, 3, {2, 1, 5}},
     {IFPHYSADDRESS, ASN_OCTET_STR, RONLY, var_ifEntry, 3, {2, 1, 6}},
-#ifdef WIN32
+#if defined (WIN32) || defined (cygwin)
     {IFADMINSTATUS, ASN_INTEGER, RWRITE, var_ifEntry, 3, {2, 1, 7}},
 #else
     {IFADMINSTATUS, ASN_INTEGER, RONLY, var_ifEntry, 3, {2, 1, 7}},
@@ -327,7 +329,7 @@ static struct ifnet *ifnetaddr_list;
  * write_method
  * 
  */
-#ifndef WIN32
+#if !defined (WIN32) && !defined (cygwin)
 static int
 header_ifEntry(struct variable *vp,
                oid * name,
@@ -1550,19 +1552,19 @@ Interface_Scan_Init(void)
         if (!strcmp(ifname_buf, "lo") && rec_pkt > 0 && !snd_pkt)
             snd_pkt = rec_pkt;
 
-        nnew->if_ipackets = rec_pkt;
+        nnew->if_ipackets = rec_pkt & 0xffffffff;
         nnew->if_ierrors = rec_err;
-        nnew->if_opackets = snd_pkt;
+        nnew->if_opackets = snd_pkt & 0xffffffff;
         nnew->if_oerrors = snd_err;
         nnew->if_collisions = coll;
         if (scan_line_to_use == scan_line_2_2) {
-            nnew->if_ibytes = rec_oct;
-            nnew->if_obytes = snd_oct;
+            nnew->if_ibytes = rec_oct & 0xffffffff;
+            nnew->if_obytes = snd_oct & 0xffffffff;
             nnew->if_iqdrops = rec_drop;
             nnew->if_snd.ifq_drops = snd_drop;
         } else {
-            nnew->if_ibytes = rec_pkt * 308;
-            nnew->if_obytes = snd_pkt * 308;
+            nnew->if_ibytes = (rec_pkt * 308) & 0xffffffff;
+            nnew->if_obytes = (snd_pkt * 308) & 0xffffffff;
         }
 
         /*
@@ -1751,16 +1753,22 @@ Interface_Scan_Next(short *Index,
         klookup((unsigned long) ifnetaddr, (char *) &ifnet, sizeof ifnet);
         klookup((unsigned long) ifnet.if_name, (char *) saveName,
                 sizeof saveName);
-#else
-        ifnet = *ifnetaddr;
-        strncpy(saveName, ifnet.if_name, sizeof(saveName));
-#endif
+
+       /*
+        * The purpose of this comparison is lost in the mists of time.
+        * It's been around at least cmu-snmp 2.1.2 for SUNv3 systems and
+        * was applied to linux systems during the cmu-snmp-linux project.
+        * No-one now knows what it was intended for, and it breaks IPv6
+        * tunnel interfaces, so it's been moved out of the Linux code block.
+        */
         if (strcmp(saveName, "ip") == 0) {
             ifnetaddr = ifnet.if_next;
             continue;
         }
-
-
+#else
+        ifnet = *ifnetaddr;
+        strncpy(saveName, ifnet.if_name, sizeof(saveName));
+#endif
 
         saveName[sizeof(saveName) - 1] = '\0';
         cp = (char *) strchr(saveName, '\0');
@@ -1886,9 +1894,10 @@ Interface_Scan_Next(short *Index,
              *  Try to find an address for this interface
              */
 
-            auto_nlist(IFADDR_SYMBOL, (char *) &ia, sizeof(ia));
 #ifdef netbsd1
             ia = (struct in_ifaddr *) ifnet.if_addrlist.tqh_first;
+#else
+            auto_nlist(IFADDR_SYMBOL, (char *) &ia, sizeof(ia));
 #endif
             while (ia) {
                 klookup((unsigned long) ia, (char *) &in_ifaddr,
@@ -1994,7 +2003,7 @@ static int      Interface_Count = 0;
 
 #if defined(hpux11)
 
-static int
+int
 Interface_Scan_Get_Count(void)
 {
     if (!Interface_Count) {
@@ -2523,7 +2532,7 @@ var_ifEntry(struct variable * vp,
 #endif                          /* HAVE_NET_IF_MIB_H */
 #endif                          /* !USE_SYSCTL_IFLIST */
 
-#else                           /* WIN32 */
+#else                           /* WIN32 cygwin */
 #include <iphlpapi.h>
 
 WriteMethod     writeIfEntry;
@@ -2635,7 +2644,7 @@ var_ifEntry(struct variable * vp,
 {
     int             ifIndex;
     static MIB_IFROW ifRow;
-    conf_if_list   *if_ptr;
+    conf_if_list   *if_ptr = NULL;
     
     ifIndex =
         header_ifEntry(vp, name, length, exact, var_len, write_method);
@@ -2809,4 +2818,4 @@ writeIfEntry(int action,
     }
     return SNMP_ERR_NOERROR;
 }                               /* end of writeIfEntry */
-#endif                          /* WIN32 */
+#endif                          /* WIN32 cygwin */
