@@ -99,9 +99,6 @@
 #  include <netinet/tcp_timer.h>
 # endif
 # if HAVE_NETINET_TCP_VAR_H
-#  if HAVE_SYS_TIMEOUT_H
-#   include <sys/timeout.h>
-#  endif
 #  include <netinet/tcp_var.h>
 # endif
 # if HAVE_NETINET_TCP_FSM_H
@@ -142,16 +139,16 @@
 #include "interfaces.h"
 
 static int header_ipv6
-(register struct variable *, oid *, size_t *, int, size_t *,
-     WriteMethod **);
+__P((register struct variable *, oid *, size_t *, int, size_t *,
+     WriteMethod **));
 static int header_ipv6_scan
-(register struct variable *, oid *, size_t *, int, size_t *,
-     WriteMethod **, int, int);
-static int if_initialize (void);
-static int if_maxifindex (void);
-static char    *if_getname (int);
+__P((register struct variable *, oid *, size_t *, int, size_t *,
+     WriteMethod **, int, int));
+static int if_initialize __P((void));
+static int if_maxifindex __P((void));
+static char    *if_getname __P((int));
 #ifdef notused
-static int if_getindex (const char *);
+static int if_getindex __P((const char *));
 #endif
 
 struct variable3 ipv6_variables[] = {
@@ -1311,7 +1308,7 @@ var_udp6(register struct variable * vp,
         newname[j++] = ntohs(in6pcb.in6p_lport);
         if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_laddr))
             newname[j++] =
-                ntohs(*(u_int16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
+                ntohs(*(uint16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
         else
             newname[j++] = 0;
         /*XXX*/
@@ -1377,7 +1374,7 @@ var_udp6(register struct variable * vp,
     case IPV6UDPIFINDEX:
         if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_laddr))
             long_return =
-                ntohs(*(u_int16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
+                ntohs(*(uint16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
         else
             long_return = 0;
         /*XXX*/ return (u_char *) & long_return;
@@ -1511,7 +1508,7 @@ var_tcp6(register struct variable * vp,
         newname[j++] = ntohs(in6pcb.in6p_fport);
         if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_laddr))
             newname[j++] =
-                ntohs(*(u_int16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
+                ntohs(*(uint16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
         else
             newname[j++] = 0;
         /*XXX*/ newname[j++] = tcp6statemap[tcp6cb.t_state];
@@ -1589,7 +1586,7 @@ var_tcp6(register struct variable * vp,
     case IPV6TCPIFINDEX:
         if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_laddr))
             long_return =
-                ntohs(*(u_int16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
+                ntohs(*(uint16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
         else
             long_return = 0;
         /*XXX*/ return (u_char *) & long_return;
@@ -1735,7 +1732,7 @@ var_tcp6(register struct variable * vp,
         newname[j++] = ntohs(in6pcb.in6p_fport);
         if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_laddr))
             newname[j++] =
-                ntohs(*(u_int16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
+                ntohs(*(uint16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
         else
             newname[j++] = 0;
         /*XXX*/ newname[j++] = mapTcpState((int)tcpcb.t_state);
@@ -1812,7 +1809,7 @@ var_tcp6(register struct variable * vp,
     case IPV6TCPIFINDEX:
         if (IN6_IS_ADDR_LINKLOCAL(&in6pcb.in6p_laddr))
             long_return =
-                ntohs(*(u_int16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
+                ntohs(*(uint16_t *) & in6pcb.in6p_laddr.s6_addr[2]);
         else
             long_return = 0;
         /*XXX*/ return (u_char *) & long_return;
@@ -2079,7 +2076,7 @@ linux_if_nameindex(void)
     FILE           *f;
     unsigned long   if_index;
     char            if_name[256];
-    struct if_nameindex *ifndx = NULL, *iflist = NULL, *ifnew;
+    struct if_nameindex *ifndx = NULL, *iflist = NULL, *new;
     int             i, j;
     int             maxidx, if_count = 0;
 
@@ -2096,17 +2093,17 @@ linux_if_nameindex(void)
             if_name[sizeof(if_name) - 1] = '\0';
             if (maxidx < 0 || maxidx < if_index) {
 
-                ifnew =
+                new =
                     realloc(iflist,
                             (sizeof(struct if_nameindex)) * (if_index +
                                                              2));
-                if (!ifnew) {
+                if (!new) {
                     linux_freeinternalnameindex(iflist, if_index);
                     if_count = 0;
                     iflist = NULL;
                     break;
                 }
-                iflist = ifnew;
+                iflist = new;
                 for (i = maxidx + 1; i <= if_index; i++)
                     memset(&iflist[i], 0, sizeof(struct if_nameindex));
                 memset(&iflist[if_index + 1], 0,
