@@ -674,7 +674,7 @@ vacm_in_view_callback(int majorID, int minorID, void *serverarg,
  *              subtree has both allowed and disallowed portions)
  *
  * Debug output listed as follows:
- *	<securityName> <groupName> <viewName> <viewType>
+ *	\<securityName\> \<groupName\> \<viewName\> \<viewType\>
  */
 int
 vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
@@ -687,6 +687,7 @@ vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
     char           *contextName = vacm_default_context;
     char           *vn;
     char           *sn = NULL;
+    char           *pdu_community;
     /*
      * len defined by the vacmContextName object 
      */
@@ -695,6 +696,9 @@ vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
 
 #if !defined(DISABLE_SNMPV1) || !defined(DISABLE_SNMPV2C)
     if (pdu->version == SNMP_VERSION_1 || pdu->version == SNMP_VERSION_2c) {
+        pdu_community = pdu->community;
+        if (!pdu_community)
+            pdu_community = "";
         if (snmp_get_do_debugging()) {
             char           *buf;
             if (pdu->community) {
@@ -725,7 +729,7 @@ vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
             ) {
             if (!netsnmp_udp_getSecName(pdu->transport_data,
                                         pdu->transport_data_length,
-                                        (char *) pdu->community,
+                                        (char *) pdu_community,
                                         pdu->community_len, &sn,
                                         &contextName)) {
                 /*
@@ -745,7 +749,7 @@ vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
             ) {
             if (!netsnmp_udp6_getSecName(pdu->transport_data,
                                          pdu->transport_data_length,
-                                         (char *) pdu->community,
+                                         (char *) pdu_community,
                                          pdu->community_len, &sn,
                                          &contextName)) {
                 /*
@@ -762,7 +766,7 @@ vacm_in_view(netsnmp_pdu *pdu, oid * name, size_t namelen,
         } else if (pdu->tDomain == netsnmp_UnixDomain){
             if (!netsnmp_unix_getSecName(pdu->transport_data,
                                          pdu->transport_data_length,
-                                         (char *) pdu->community,
+                                         (char *) pdu_community,
                                          pdu->community_len, &sn,
                                          &contextName)) {
 					sn = NULL;
