@@ -73,7 +73,7 @@ PERFORMANCE OF THIS SOFTWARE.
 
 extern WriteMethod write_rte;
 
-#ifndef WIN32
+#if !defined (WIN32) && !defined (cygwin)
 
 #ifdef USE_SYSCTL_ROUTE_DUMP
 
@@ -1393,7 +1393,7 @@ qsort_compare(const void *v1, const void *v2)
 
 #endif                          /* solaris2 */
 
-#else                           /* WIN32 */
+#else                           /* WIN32 cygwin */
 #include <iphlpapi.h>
 #ifndef MIB_IPPROTO_NETMGMT
 #define MIB_IPPROTO_NETMGMT 3
@@ -1617,7 +1617,7 @@ var_ipRouteEntry(struct variable *vp,
     return NULL;
 }
 
-#endif                          /* WIN32 */
+#endif                          /* WIN32 cygwin */
 
 #else                           /* CAN_USE_SYSCTL */
 
@@ -1957,7 +1957,7 @@ snmp_socket_length(int family)
 
     switch (family) {
 #ifndef cygwin
-#ifndef WIN32
+#if !defined (WIN32) && !defined (cygwin)
 #ifdef AF_UNIX
     case AF_UNIX:
         length = sizeof(struct sockaddr_un);
