@@ -178,7 +178,7 @@ init_diskio(void)
     kc = kstat_open();
 
     if (kc == NULL)
-        snmp_log(LOG_ERR, "diskio: Couln't open kstat\n");
+        snmp_log(LOG_ERR, "diskio: Couldn't open kstat\n");
 #endif
 
 #ifdef darwin
@@ -445,13 +445,12 @@ void devla_getstats(unsigned int regno, void *dummy) {
 	if (lastat == NULL) {
 	    lastat = (struct statinfo *) malloc(sizeof(struct statinfo));
 	    if (lastat != NULL)
-		lastat->dinfo = (struct devinfo *) malloc(sizeof(struct devinfo));
+		lastat->dinfo = (struct devinfo *) calloc(sizeof(struct devinfo), 1);
 	    if (lastat == NULL || lastat->dinfo == NULL) {
 		    SNMP_FREE(lastat);
 		    ERROR_MSG("Memory alloc failure - devla_getstats()\n");
 		    return;
 	    }
-	    memset(lastat->dinfo, 0, sizeof(struct devinfo));
 	}
 
         if ((GETDEVS(lastat)) == -1) {
@@ -522,14 +521,13 @@ getstats(void)
     if (stat == NULL) {
         stat = (struct statinfo *) malloc(sizeof(struct statinfo));
         if (stat != NULL)
-            stat->dinfo = (struct devinfo *) malloc(sizeof(struct devinfo));
+            stat->dinfo = (struct devinfo *) calloc(sizeof(struct devinfo), 1);
         if (stat == NULL || stat->dinfo == NULL) {
 		SNMP_FREE(stat);
         	ERROR_MSG("Memory alloc failure - getstats\n");
 		return 1;
 	}
     }
-    memset(stat->dinfo, 0, sizeof(struct devinfo));
 
     if (GETDEVS(stat) == -1) {
         fprintf(stderr, "Can't get devices:%s\n", devstat_errbuf);
@@ -689,13 +687,11 @@ int getstats(void)
 	    }
 	    pTemp = &head.indices[head.length];
 	    sscanf (buffer, "%d %d", &pTemp->major, &pTemp->minor);
-	    if (pTemp->minor == 0)
-		sscanf (buffer, "%d %d %s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
+ 	    if (sscanf (buffer, "%d %d %s %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu %lu\n",
 		    &pTemp->major, &pTemp->minor, pTemp->name,
 		    &pTemp->rio, &pTemp->rmerge, &pTemp->rsect, &pTemp->ruse,
 		    &pTemp->wio, &pTemp->wmerge, &pTemp->wsect, &pTemp->wuse,
-		    &pTemp->running, &pTemp->use, &pTemp->aveq);
-	    else
+ 		    &pTemp->running, &pTemp->use, &pTemp->aveq) != 14)
 		sscanf (buffer, "%d %d %s %lu %lu %lu %lu\n",
 		    &pTemp->major, &pTemp->minor, pTemp->name,
 		    &pTemp->rio, &pTemp->rsect,
