@@ -21,6 +21,19 @@
  * information.  Later platforms, such as the V880 use the picld
  * daemon to control system resources and report sensor information.
  * Picld is supported only on Solaris 2.8 and later.
+ * 
+ * KSTAT
+ *
+ * The code initializes the kstat variables, then does a specific inquiry
+ * for what we're looking for.
+ *
+ * PICLD
+ *
+ * If picld is available on the platform, it tries to initialize picld.
+ * If that works, it points itself to the top of the picld btree
+ * and walks it way down recursively looking for sensors and child leafs.
+ * If it finds a child, it goes in and works it way down recursively.
+ * If it finds a sensor, it deals with it.
  *
  * Both these methodologies are implemented in a "read only" manner.
  * You cannot use this code to change anything eg. fan speeds.
@@ -78,7 +91,7 @@
     #ifdef HAVE_PICL_H 
         #include <picl.h> /* accesses the picld daemon */
     #endif 
-    #include </usr/platform/sun4u/include/sys/envctrl.h>
+    #include </usr/platform/sun4u/include/sys/envctrl.h> /*should this be more generic? */
 #else
     #include <sensors/sensors.h>
     #define CONFIG_FILE_NAME "/etc/sensors.conf"
@@ -215,7 +228,6 @@ var_lmSensorsTable(struct variable *vp,
 {
     static long     long_ret;
     static unsigned char string[SPRINT_MAX_LEN];
-    int             i;  /* generates a variable not used error message in Solaris - that's OK */
 
     int             s_index;
     int             s_type = -1;
@@ -303,9 +315,7 @@ var_lmSensorsTable(struct variable *vp,
 static int
 sensor_init(void)
 {
-#ifdef solaris2
-    clock_t         t = time(NULL);
-#else
+#ifndef solaris2
     int             res;
     char            filename[] = CONFIG_FILE_NAME;
     clock_t         t = clock();
@@ -313,7 +323,7 @@ sensor_init(void)
     if (!fp)
         return 1;
 
-    if (res = sensors_init(fp))
+    if ((res = sensors_init(fp)))
         return 2;
 
     _sensor_load(t); /* I'll let the linux people decide whether they want to load right away */
@@ -344,7 +354,7 @@ sensor_load(void)
 /* *******  picld sensor procedures * */
 #ifdef HAVE_PICL_H
 
-static int
+static void
 process_individual_fan(picl_nodehdl_t childh, 
                      char propname[PICL_PROPNAMELEN_MAX])
 {
@@ -357,8 +367,7 @@ process_individual_fan(picl_nodehdl_t childh,
     picl_errno_t    error_code,ec2;
 
     if (sensor_array[typ].n >= MAX_SENSORS){
-        DEBUGMSG(("ucd-snmp/lmSensors",
-            "There are too many sensors of type %d\n",typ));
+        snmp_log(LOG_ERR, "There are too many sensors of type %d\n",typ);
         }
     else{
         error_code = (picl_get_propinfo_by_name(childh,
@@ -374,16 +383,16 @@ process_individual_fan(picl_nodehdl_t childh,
                  sensor_array[typ].n++;
                  } /*end if ec2*/
              else
-                 DEBUGMSG(("ucd-snmp/lmSensors", 
+                 DEBUGMSGTL(("ucd-snmp/lmSensors", 
                      "sensor value read error code->%d\n",ec2));
             } /* end if */
         else
-            DEBUGMSG(("ucd-snmp/lmSensors", 
+            DEBUGMSGTL(("ucd-snmp/lmSensors", 
                 "sensor lookup failed  error code->%d\n",error_code));
         }
 } /*process individual fan*/
 
-static int
+static void
 process_temperature_sensor(picl_nodehdl_t childh,
                                char propname[PICL_PROPNAMELEN_MAX])
 {
@@ -396,8 +405,7 @@ process_temperature_sensor(picl_nodehdl_t childh,
     picl_errno_t    error_code,ec2;
 
     if (sensor_array[typ].n >= MAX_SENSORS){
-        DEBUGMSG(("ucd-snmp/lmSensors",
-            "There are too many sensors of type %d\n",typ));
+        snmp_log(LOG_ERR, "There are too many sensors of type %d\n",typ);
         }
     else{
         error_code = (picl_get_propinfo_by_name(childh,
@@ -413,16 +421,16 @@ process_temperature_sensor(picl_nodehdl_t childh,
                  sensor_array[typ].n++;
                  } /*end if ec2*/
              else
-                 DEBUGMSG(("ucd-snmp/lmSensors", 
+                 DEBUGMSGTL(("ucd-snmp/lmSensors", 
                                "sensor value read error code->%d\n",ec2));
             } /* end if */
         else
-            DEBUGMSG(("ucd-snmp/lmSensors", 
+            DEBUGMSGTL(("ucd-snmp/lmSensors", 
                 "sensor lookup failed  error code->%d\n",error_code));
         }
 }  /* process temperature sensor */
 
-static int
+static void
 process_digital_sensor(picl_nodehdl_t childh,
                    char propname[PICL_PROPNAMELEN_MAX])
 {
@@ -435,8 +443,7 @@ process_digital_sensor(picl_nodehdl_t childh,
     picl_errno_t    error_code,ec2;
 
     if (sensor_array[typ].n >= MAX_SENSORS){
-        DEBUGMSG(("ucd-snmp/lmSensors",
-            "There are too many sensors of type %d\n",typ));
+        snmp_log(LOG_ERR, "There are too many sensors of type %d\n",typ);
         }
     else{
         error_code = (picl_get_propinfo_by_name(childh,
@@ -452,16 +459,16 @@ process_digital_sensor(picl_nodehdl_t childh,
                  sensor_array[typ].n++;
                  }
              else
-                 DEBUGMSG(("ucd-snmp/lmSensors", 
+                 DEBUGMSGTL(("ucd-snmp/lmSensors", 
                    "sensor value read error code->%d\n",ec2));
             } /* end if */
         else
-            DEBUGMSG(("ucd-snmp/lmSensors", 
+            DEBUGMSGTL(("ucd-snmp/lmSensors", 
               "sensor lookup failed  error code->%d\n",error_code));
         }
 }  /* process digital sensor */
 
-static int
+static void
 process_switch(picl_nodehdl_t childh,
                    char propname[PICL_PROPNAMELEN_MAX])
 {
@@ -470,7 +477,7 @@ process_switch(picl_nodehdl_t childh,
 
     char state[32];
     int st_cnt;
-    char *switch_settings[]={"OFF","ON","NORMAL","LOCKED","UNKNOWN",
+    const char *switch_settings[]={"OFF","ON","NORMAL","LOCKED","UNKNOWN",
                                     "DIAG","SECURE"};
     u_int value;
     u_int found = 0;
@@ -478,8 +485,7 @@ process_switch(picl_nodehdl_t childh,
     int typ = 3; /*other*/
 
     if (sensor_array[typ].n >= MAX_SENSORS){
-        DEBUGMSG(("ucd-snmp/lmSensors",
-            "There are too many sensors of type %d\n",typ));
+        snmp_log(LOG_ERR, "There are too many sensors of type %d\n",typ);
         }
     else{
         picl_errno_t    error_code,ec2;
@@ -507,16 +513,16 @@ process_switch(picl_nodehdl_t childh,
                  sensor_array[typ].n++;
                  } /*end if ec2*/
              else
-                 DEBUGMSG(("ucd-snmp/lmSensors",
+                 DEBUGMSGTL(("ucd-snmp/lmSensors",
                      "sensor value read error code->%d\n",ec2));
             } /* end if */
         else
-            DEBUGMSG(("ucd-snmp/lmSensors",
+            DEBUGMSGTL(("ucd-snmp/lmSensors",
                 "sensor lookup failed  error code->%d\n",error_code));
         }
 } /*process switch*/
 
-static int
+static void
 process_led(picl_nodehdl_t childh,
                    char propname[PICL_PROPNAMELEN_MAX])
 {
@@ -525,7 +531,7 @@ process_led(picl_nodehdl_t childh,
 
     char state[32];
     int st_cnt;
-    char *led_settings[]={"OFF","ON","BLINK"};
+    const char *led_settings[]={"OFF","ON","BLINK"};
     u_int value;
     u_int found = 0;
     int max_led_posns = 3;
@@ -534,8 +540,7 @@ process_led(picl_nodehdl_t childh,
     picl_errno_t    error_code,ec2;
 
     if (sensor_array[typ].n >= MAX_SENSORS){
-        DEBUGMSG(("ucd-snmp/lmSensors",
-            "There are too many sensors of type %d\n",typ));
+        snmp_log(LOG_ERR, "There are too many sensors of type %d\n",typ);
         }
     else{
         error_code = (picl_get_propinfo_by_name(childh,
@@ -561,16 +566,16 @@ process_led(picl_nodehdl_t childh,
                  sensor_array[typ].n++;
                  }
              else
-                 DEBUGMSG(("ucd-snmp/lmSensors",
+                 DEBUGMSGTL(("ucd-snmp/lmSensors",
                      "sensor value read error code->%d\n",ec2));
             } 
         else
-            DEBUGMSG(("ucd-snmp/lmSensors",
+            DEBUGMSGTL(("ucd-snmp/lmSensors",
                 "sensor lookup failed  error code->%d\n",error_code));
        }
 } 
 
-static int
+static void
 process_i2c(picl_nodehdl_t childh,
                    char propname[PICL_PROPNAMELEN_MAX])
 {
@@ -579,7 +584,7 @@ process_i2c(picl_nodehdl_t childh,
 
     char state[32];
     int st_cnt;
-    char *i2c_settings[]={"OK"};
+    const char *i2c_settings[]={"OK"};
     u_int value;
     u_int found = 0;
     int max_i2c_posns = 1;
@@ -588,13 +593,13 @@ process_i2c(picl_nodehdl_t childh,
     picl_errno_t    error_code,ec2;
 
     if (sensor_array[typ].n >= MAX_SENSORS){
-        DEBUGMSG(("ucd-snmp/lmSensors",
-            "There are too many sensors of type %d\n",typ));
+        snmp_log(LOG_ERR, "There are too many sensors of type %d\n",typ);
         }
     else{
         error_code = (picl_get_propinfo_by_name(childh,
                          "State",&sensor_info,&sensorh));
         if (error_code == PICL_SUCCESS) {
+             DEBUGMSGTL(("ucd-snmp/lmSensors","Found i2c record size %d\n",sensor_info.size));
              ec2 = picl_get_propval(sensorh,&state,sensor_info.size);
              if (ec2 == PICL_SUCCESS){
                  for (st_cnt=0;st_cnt < max_i2c_posns;st_cnt++){
@@ -615,138 +620,105 @@ process_i2c(picl_nodehdl_t childh,
                  sensor_array[typ].n++;
                  } 
              else
-                 DEBUGMSG(("ucd-snmp/lmSensors",
+                 DEBUGMSGTL(("ucd-snmp/lmSensors",
                      "sensor value read error code->%d\n",ec2));
             }
         else
-            DEBUGMSG(("ucd-snmp/lmSensors",
+            DEBUGMSGTL(("ucd-snmp/lmSensors",
                 "sensor lookup failed  error code->%d\n",error_code));
         }
 }
 
 static int
-process_sensors(picl_nodehdl_t nodeh)
+process_sensors(int level, picl_nodehdl_t nodeh)
 {
     picl_nodehdl_t  childh;
-    picl_nodehdl_t  nexth;
 
-    char            propname[PICL_PROPNAMELEN_MAX];
-    char            propclass[PICL_CLASSNAMELEN_MAX];
-    picl_errno_t    error_code;
+    char		propname[PICL_PROPNAMELEN_MAX];
+    char		propclass[PICL_CLASSNAMELEN_MAX];
+    picl_errno_t	error_code;
+    picl_prophdl_t	prop_handle;
+    picl_propinfo_t	prop_info;
 
-    /* look up first child node */
-    error_code = picl_get_propval_by_name(nodeh, PICL_PROP_CHILD, &childh,
-                                        sizeof (picl_nodehdl_t));
+
+    level++;
+/*
+    DEBUGMSGTL(("ucd-snmp/lmSensors","Processing sensors level %d\n",level));
+*/
+
+    error_code = picl_get_propval_by_name(nodeh, PICL_PROP_CLASSNAME, propclass,
+                                        (PICL_PROPNAMELEN_MAX-1));
     if (error_code != PICL_SUCCESS) {
+        DEBUGMSG(("ucd-snmp/lmSensors","Couldn't get propclass\n"));
                 return (error_code);
     }
 
-    /* step through child nodes, get the name first */
-    while (error_code == PICL_SUCCESS) {
-        error_code = picl_get_propval_by_name(childh, PICL_PROP_NAME,
-                                               propname, (PICL_PROPNAMELEN_MAX - 1));
-        if (error_code != PICL_SUCCESS) {  /*we found a node with no name.  Impossible.! */
-            return (error_code);
-        }
+    error_code = picl_get_prop_by_name(nodeh, PICL_PROP_NAME, &prop_handle);
 
-        if (strcmp(propname,PICL_NODE_PLATFORM)==0){ /*end of the chain*/
-                return (255);
-        }
-
-        error_code = picl_get_propval_by_name(childh, PICL_PROP_CLASSNAME,
-                                                propclass, sizeof (propclass));
-        if (error_code != PICL_SUCCESS) {  /*we found a node with no class.  Impossible.! */
-            return (error_code);
-        }
-
-/*        DEBUGMSGTL(("ucd-snmp/lmSensors","found %s of class %s\n",propname,propclass)); */
-
-        if (strstr(propclass,"fan-tachometer"))
-            process_individual_fan(childh,propname);
-        if (strstr(propclass,"temperature-sensor"))
-            process_temperature_sensor(childh,propname);
-        if (strstr(propclass,"digital-sensor"))
-            process_digital_sensor(childh,propname);
-        if (strstr(propclass,"switch"))
-            process_switch(childh,propname);
-        if (strstr(propclass,"led"))
-            process_led(childh,propname);
-        if (strstr(propclass,"i2c"))
-            process_i2c(childh,propname);
-/*
-        if (strstr(propclass,"gpio"))
-            process_gpio(childh,propname); 
-*/
-
-
-           /* look for children of children (note, this is recursive) */
- 
-        if (process_sensors(childh) == PICL_SUCCESS) {
-            return (PICL_SUCCESS);
-        }
-
-          /* get next child node at this level*/
-        error_code = picl_get_propval_by_name(childh, PICL_PROP_PEER,
-                                        &nexth, sizeof (picl_nodehdl_t));
-        if (error_code != PICL_SUCCESS) {/* no more children - buh bye*/
-            return (error_code);
-        }
-
-        childh = nexth;
-
-    } /* while */
-    return (error_code);
-} /* process sensors */
-
-static int
-get_child(picl_nodehdl_t nodeh, char *cname, picl_nodehdl_t *resulth)
-{
-    picl_nodehdl_t  childh;
-    picl_nodehdl_t  nexth;
-
-    char            pname[PICL_PROPNAMELEN_MAX];
-    picl_errno_t    error_code;
-
-    /* look up first child node */
-    error_code = picl_get_propval_by_name(nodeh, PICL_PROP_CHILD, &childh,
-                                        sizeof (picl_nodehdl_t));
     if (error_code != PICL_SUCCESS) {
-            return (error_code);
+        DEBUGMSGTL(("ucd-snmp/lmSensors","Couldn't get prop_handle\n"));
+        return (error_code);
+
     }
 
-    /* step through child nodes, get the name first */
-    while (error_code == PICL_SUCCESS) {
-        error_code = picl_get_propval_by_name(childh, PICL_PROP_NAME,
-                                              pname, (PICL_PROPNAMELEN_MAX - 1));
-        if (error_code != PICL_SUCCESS) {  /*we found a node with no name.  Impossible.! */
+    error_code = picl_get_propinfo(prop_handle, &prop_info);
+
+    if (error_code != PICL_SUCCESS) {
+        DEBUGMSGTL(("ucd-snmp/lmSensors","Couldn't get prop information\n"));
+        return (error_code);
+
+    }
+
+    error_code=picl_get_propval(prop_handle, propname, (PICL_PROPNAMELEN_MAX-1));
+
+    DEBUGMSGTL(("ucd-snmp/lmSensors","found propname %s of class %s\n",propname, propclass));
+
+    if (error_code != PICL_SUCCESS) {
+        DEBUGMSGTL(("ucd-snmp/lmSensors","Couldn't get prop handle by name\n"));
+        return (error_code);
+
+    }
+
+    if (strstr(propclass,"flashprom"))
+       DEBUGMSGTL(("ucd-snmp/lmSensors","found a flashprom\n"));
+    if (strstr(propclass,"fan-tachometer"))
+        process_individual_fan(nodeh,propname);
+    if (strstr(propclass,"temperature-sensor"))
+        process_temperature_sensor(nodeh,propname);
+    if (strstr(propclass,"digital-sensor"))
+        process_digital_sensor(nodeh,propname);
+    if (strstr(propclass,"switch"))
+        process_switch(nodeh,propname);
+    if (strstr(propclass,"led"))
+        process_led(nodeh,propname);
+    if (strstr(propclass,"i2c"))
+        process_i2c(nodeh,propname);
+/*
+        if (strstr(propclass,"gpio"))
+            process_gpio(prop_handle,propname); 
+*/
+    for (error_code = picl_get_propval_by_name(nodeh, PICL_PROP_CHILD,
+          &childh, sizeof (picl_nodehdl_t)); 
+          error_code != PICL_PROPNOTFOUND;
+          error_code = picl_get_propval_by_name(childh, PICL_PROP_PEER,
+           &childh, sizeof (picl_nodehdl_t))) {
+       if (error_code != PICL_SUCCESS) {
             return (error_code);
-        }
+          }
 
-        if (strncmp(pname, cname,PICL_PROPNAMELEN_MAX) == 0){
-            *resulth = childh;
-            return (PICL_SUCCESS);
-        }
+       /* call itself recursively */
+
+       error_code = process_sensors(level,childh);
+
+       if (error_code != PICL_SUCCESS)
+           return (error_code);
+
+       } /* end for */
+
+    return (PICL_SUCCESS);
 
 
-        /* look for children of children (note, this is recursive) */
-
-        if (get_child(childh,cname,resulth) == PICL_SUCCESS) {
-             return (PICL_SUCCESS);
-        }
-
-        /* get next child node at this level*/
-            
-        error_code = picl_get_propval_by_name(childh, PICL_PROP_PEER,
-                                        &nexth, sizeof (picl_nodehdl_t));
-        if (error_code != PICL_SUCCESS) {/* no more children - buh bye*/
-            return (error_code);
-        }
-
-        childh = nexth;
-
-    } /* while */
-    return (error_code);
-} /* get child */
+} /* process sensors */
 
 #endif
 /* ******** end of picld sensor procedures * */
@@ -761,8 +733,7 @@ _sensor_load(clock_t t)
     int typ;
     int temp;
     int other;
-    int er_code;
-    char *fantypes[]={"CPU","PWR","AFB"};
+    const char *fantypes[]={"CPU","PWR","AFB"};
     kstat_ctl_t *kc;
     kstat_t *kp;
     envctrl_fan_t *fan_info;
@@ -770,12 +741,13 @@ _sensor_load(clock_t t)
     envctrl_encl_t *enc_info;
 
 #ifdef HAVE_PICL_H
+    int er_code;
     picl_errno_t     error_code;
-    picl_nodehdl_t  rooth,plath;
-    char sname[PICL_PROPNAMELEN_MAX] = "SYSTEM";
+    int level=0;
+    picl_nodehdl_t  rooth;
 #endif 
 
-/* DEBUGMSG(("ucd-snmp/lmSensors", "Reading the sensors\n")); */
+ DEBUGMSGTL(("ucd-snmp/lmSensors", "Reading the sensors\n")); 
 
 /* initialize the array */
     for (i = 0; i < N_TYPES; i++){
@@ -786,63 +758,58 @@ _sensor_load(clock_t t)
              }
         } /*end for i*/
 
-/* try picld (if supported), if that doesn't work, try kstat */
+/* try picld (if supported), then try kstat */
 #ifdef HAVE_PICL_H 
 
+DEBUGMSGTL(("ucd-snmp/lmSensors","trying picld first\n"));
+
 er_code = picl_initialize();
 
 if (er_code == PICL_SUCCESS) {
 
+    DEBUGMSGTL(("ucd-snmp/lmSensors","Got into picld\n"));
+
     error_code = picl_get_root(&rooth);
 
     if (error_code != PICL_SUCCESS) {
-        DEBUGMSG(("ucd-snmp/lmSensors", "picld couldn't get root error code->%d\n",error_code));
+        DEBUGMSGTL(("ucd-snmp/lmSensors", "picld couldn't get root error code->%d\n",error_code));
         }
     else{
-        error_code = get_child(rooth,sname,&plath);
-
-        if (error_code == PICL_SUCCESS){
-            error_code = process_sensors(plath);
-
-            if (error_code != 255) 
-                if (error_code != 7)
-                    DEBUGMSG(("ucd-snmp/lmSensors", "picld had an internal problem error code->%d\n",error_code));
-            } /* endif error_code */
-        else{
-            DEBUGMSG(("ucd-snmp/lmSensors", "picld couldn't get system tree error code->%d\n",error_code));
-            } /* end else error_code */
-        } /* end else */
+        DEBUGMSGTL(("ucd-snmp/lmSensors", "found root\n"));
+        error_code = process_sensors(level, rooth);
+       } /* end else */
 
     picl_shutdown();
 
 }  /* end if err_code for picl_initialize */
+else {
+    DEBUGMSGTL(("ucd-snmp/lmSensors","No picld available\n"));
 
-else{  /* try kstat instead */
-
-    DEBUGMSG(("ucd-snmp/lmSensors", "picld couldn't initialize picld because error code->%d\n",er_code));
+} /*end else picl_initialize */
 
 #endif  /* end of picld section */
 /* initialize kstat */
 
 kc = kstat_open();
 if (kc == 0) {
-    DEBUGMSG(("ucd-snmp/lmSensors", "couldn't open kstat"));
+    DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't open kstat\n"));
     } /* endif kc */
 else{
+    DEBUGMSGTL(("ucd-snmp/lmSensors", "Opened kstat - looking for sensors\n"));
     kp = kstat_lookup(kc, ENVCTRL_MODULE_NAME, 0, ENVCTRL_KSTAT_FANSTAT);
     if (kp == 0) {
-        DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't lookup fan kstat"));
+        DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't lookup fan kstat\n"));
         } /* endif lookup fans */
     else{
         if (kstat_read(kc, kp, 0) == -1) {
-            DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't read fan kstat"));
+            DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't read fan kstat\n"));
             } /* endif kstatread fan */
         else{
             typ = 1;
             fan_info = (envctrl_fan_t *) kp->ks_data;
             sensor_array[typ].n = kp->ks_ndata;
             for (i=0; i < kp->ks_ndata; i++){
-                DEBUGMSG(("ucd-snmp/lmSensors", "found instance %d fan type %d speed %d OK %d bustedfan %d\n",
+                DEBUGMSGTL(("ucd-snmp/lmSensors", "found instance %d fan type %d speed %d OK %d bustedfan %d\n",
                     fan_info->instance, fan_info->type,fan_info->fanspeed,fan_info->fans_ok,fan_info->fanflt_num));
                 sensor_array[typ].sensor[i].value = fan_info->fanspeed;
                 snprintf(sensor_array[typ].sensor[i].name,(MAX_NAME - 1),
@@ -856,18 +823,18 @@ else{
 
     kp = kstat_lookup(kc, ENVCTRL_MODULE_NAME, 0, ENVCTRL_KSTAT_PSNAME);
     if (kp == 0) {
-        DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't lookup power supply kstat"));
+        DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't lookup power supply kstat\n"));
         } /* endif lookup power supply */
     else{
         if (kstat_read(kc, kp, 0) == -1) {
-            DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't read power supply kstat"));
+            DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't read power supply kstat\n"));
             } /* endif kstatread fan */
         else{
             typ = 2;
             power_info = (envctrl_ps_t *) kp->ks_data;
             sensor_array[typ].n = kp->ks_ndata;
             for (i=0; i < kp->ks_ndata; i++){
-                DEBUGMSG(("ucd-snmp/lmSensors", "found instance %d psupply temp %d %dW OK %d share %d limit %d\n",
+                DEBUGMSGTL(("ucd-snmp/lmSensors", "found instance %d psupply temp %d %dW OK %d share %d limit %d\n",
                     power_info->instance, power_info->ps_tempr,power_info->ps_rating,
                     power_info->ps_ok,power_info->curr_share_ok,power_info->limit_ok));
                 sensor_array[typ].sensor[i].value = power_info->ps_tempr;
@@ -881,11 +848,11 @@ else{
 
     kp = kstat_lookup(kc, ENVCTRL_MODULE_NAME, 0, ENVCTRL_KSTAT_ENCL);
     if (kp == 0) {
-        DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't lookup enclosure kstat"));
+        DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't lookup enclosure kstat\n"));
         } /* endif lookup enclosure */
     else{
         if (kstat_read(kc, kp, 0) == -1) {
-            DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't read enclosure kstat"));
+            DEBUGMSGTL(("ucd-snmp/lmSensors", "couldn't read enclosure kstat\n"));
             } /* endif kstatread enclosure */
         else{
             enc_info = (envctrl_encl_t *) kp->ks_data; 
@@ -894,7 +861,7 @@ else{
             for (i=0; i < kp->ks_ndata; i++){
                switch (enc_info->type){
                case ENVCTRL_ENCL_FSP:
-                   DEBUGMSG(("ucd-snmp/lmSensors", "front panel value %d\n",enc_info->value));
+                   DEBUGMSGTL(("ucd-snmp/lmSensors", "front panel value %d\n",enc_info->value));
                    typ = 3; /* misc */
                    sensor_array[typ].sensor[other].value = enc_info->value;
                    strncpy(sensor_array[typ].sensor[other].name,"FSP",MAX_NAME-1);
@@ -902,7 +869,7 @@ else{
                    other++;
                    break;
                case ENVCTRL_ENCL_AMBTEMPR:
-                   DEBUGMSG(("ucd-snmp/lmSensors", "ambient temp %d\n",enc_info->value));
+                   DEBUGMSGTL(("ucd-snmp/lmSensors", "ambient temp %d\n",enc_info->value));
                    typ = 0; /* temperature sensor */
                    sensor_array[typ].sensor[temp].value = enc_info->value;
                    strncpy(sensor_array[typ].sensor[temp].name,"Ambient",MAX_NAME-1);
@@ -910,7 +877,7 @@ else{
                    temp++;
                    break;
                case ENVCTRL_ENCL_BACKPLANE4:
-                   DEBUGMSG(("ucd-snmp/lmSensors", "There is a backplane4\n"));
+                   DEBUGMSGTL(("ucd-snmp/lmSensors", "There is a backplane4\n"));
                    typ = 3; /* misc */
                    sensor_array[typ].sensor[other].value = enc_info->value;
                    strncpy(sensor_array[typ].sensor[other].name,"Backplane4",MAX_NAME-1);
@@ -918,7 +885,7 @@ else{
                    other++;
                    break;
                case ENVCTRL_ENCL_BACKPLANE8:
-                   DEBUGMSG(("ucd-snmp/lmSensors", "There is a backplane8\n"));
+                   DEBUGMSGTL(("ucd-snmp/lmSensors", "There is a backplane8\n"));
                    typ = 3; /* misc */
                    sensor_array[typ].sensor[other].value = enc_info->value;
                    strncpy(sensor_array[typ].sensor[other].name,"Backplane8",MAX_NAME-1);
@@ -926,7 +893,7 @@ else{
                    other++;
                    break;
                case ENVCTRL_ENCL_CPUTEMPR:
-                   DEBUGMSG(("ucd-snmp/lmSensors", "CPU%d temperature %d\n",enc_info->instance,enc_info->value));
+                   DEBUGMSGTL(("ucd-snmp/lmSensors", "CPU%d temperature %d\n",enc_info->instance,enc_info->value));
                    typ = 0; /* temperature sensor */
                    sensor_array[typ].sensor[temp].value = enc_info->value;
                    snprintf(sensor_array[typ].sensor[temp].name,MAX_NAME,"CPU%d",enc_info->instance);
@@ -934,7 +901,7 @@ else{
                    temp++;
                    break;
                default:
-                   DEBUGMSG(("ucd-snmp/lmSensors", "unknown element instance &d type &d value %d\n",
+                   DEBUGMSGTL(("ucd-snmp/lmSensors", "unknown element instance &d type &d value %d\n",
                        enc_info->instance, enc_info->type, enc_info->value));
                    break;
                } /* end switch */
@@ -947,9 +914,6 @@ else{
 
     kstat_close(kc);
 
-#ifdef HAVE_PICL_H
-    } /* end else kc not needed if no picld*/
-#endif
 
 } /* end else kstat */
 #else /* end solaris2 */
@@ -962,10 +926,10 @@ else{
     for (i = 0; i < N_TYPES; i++)
         sensor_array[i].n = 0;
 
-    while (chip = sensors_get_detected_chips(&chip_nr)) {
+    while ((chip = sensors_get_detected_chips(&chip_nr))) {
 	int             a = 0;
 	int             b = 0;
-        while (data = sensors_get_all_features(*chip, &a, &b)) {
+        while ((data = sensors_get_all_features(*chip, &a, &b))) {
             char           *label = NULL;
             double          val;
 
@@ -1002,7 +966,7 @@ else{
                 }
                 strncpy(array->sensor[array->n].name, label, MAX_NAME);
                 array->sensor[array->n].value = (int) (val * mul);
-                DEBUGMSGTL(("sensors","sensor %d, value %d\n",
+                DEBUGMSGTL(("ucd-snmp/lmSensors","sensor %d, value %d\n",
                             array->sensor[array->n].name,
                             array->sensor[array->n].value));
                 array->n++;
@@ -1016,4 +980,3 @@ else{
 #endif /*else solaris2 */
     timestamp = t;
 }
-
