@@ -178,7 +178,6 @@ typedef long    fd_mask;
 #define TIMETICK         500000L
 
 int             snmp_dump_packet;
-int             running = 1;
 int             reconfig = 0;
 int             Facility = LOG_DAEMON;
 
@@ -194,6 +193,7 @@ LPTSTR          app_name = _T("Net-SNMP Agent");     /* Application Name */
 const char     *app_name = "snmpd";
 #endif
 
+extern int      netsnmp_running;
 extern char   **argvrestartp;
 extern char    *argvrestart;
 extern char    *argvrestartname;
@@ -347,7 +347,7 @@ SnmpdShutDown(int a)
 #ifdef WIN32SERVICE
     extern netsnmp_session *main_session;
 #endif
-    running = 0;
+    netsnmp_running = 0;
 #ifdef WIN32SERVICE
     /*
      * In case of windows, select() in receive() function will not return 
@@ -1061,7 +1061,7 @@ receive(void)
     /*
      * Loop-forever: execute message handlers for sockets with data
      */
-    while (running) {
+    while (netsnmp_running) {
         if (reconfig) {
             reconfig = 0;
             snmp_log(LOG_INFO, "Reconfiguring daemon\n");
@@ -1210,7 +1210,7 @@ receive(void)
                      * likely that we got a signal. Check our special signal
                      * flags before retrying select.
                      */
-		    if (running && !reconfig) {
+		    if (netsnmp_running && !reconfig) {
                         goto reselect;
 		    }
                     continue;
