@@ -317,6 +317,9 @@ processFileArgs(char *fileName)
 void
 wait_for_period(int period)
 {
+#ifdef WIN32
+    Sleep(period * 1000);
+#else                   /* WIN32 */
     struct timeval  m_time, *tv = &m_time;
     struct tm       tm;
     int             count;
@@ -367,6 +370,7 @@ wait_for_period(int period)
             break;
         }
     }
+#endif                   /* WIN32 */
 }
 
 oid             sysUpTimeOid[9] = { 1, 3, 6, 1, 2, 1, 1, 3, 0 };
