@@ -42,41 +42,32 @@ static char sccsid[] = "@(#)inet.c	8.4 (Berkeley) 4/20/94";
 
 #include <net-snmp/net-snmp-config.h>
 
-/*
- * hack-o-matic for Cygwin to use winsock2
-*/
-#if defined(cygwin)
-#undef HAVE_UNISTD_H
-#undef HAVE_NETINET_IN_H
-#undef HAVE_ARPA_INET_H
-#undef HAVE_SYS_PARAM_H
-#undef HAVE_SYS_SELECT_H
-#undef HAVE_SYS_SOCKET_H
-#undef HAVE_IN_ADDR_T
-#endif
-
-#if defined(HAVE_WINSOCK_H) || defined(cygwin)
-#include <winsock2.h>
-#include <ws2tcpip.h>
-#include "winstub.h"
-
-extern const char *inet_ntop(int, const void*, char*, size_t);
-
-#ifdef cygwin
-extern int WSAAPI getnameinfo(const struct sockaddr*,socklen_t,char*,DWORD, char*,DWORD,int);
-#endif
-
-#else                  /* WIN32 */
-#if HAVE_NETDB_H
-#include <netdb.h>
-#endif
-#endif                  /* WIN32 */
-
-#include <net-snmp/net-snmp-includes.h>
-
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#if HAVE_WINSOCK_H
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#include "winstub.h"
+#endif
+#if HAVE_SYS_SOCKET_H
+#include <sys/socket.h>
+#endif
+#if HAVE_NETDB_H
+#include <netdb.h>
+#endif
+#if HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+
+#if HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+#if HAVE_ARPA_INET_H
+#include <arpa/inet.h>
+#endif
+
+#include <net-snmp/net-snmp-includes.h>
 
 #include "main.h"
 #include "netstat.h"
