@@ -136,6 +136,8 @@ typedef long    fd_mask;
 #define FD_ZERO(p)      memset((p), 0, sizeof(*(p)))
 #endif
 
+extern int      netsnmp_running;
+
 char           *logfile = 0;
 int             Log = 0;
 int             Print = 0;
@@ -143,7 +145,6 @@ int             Syslog = 0;
 int             SyslogTrap = 0;
 int             Event = 0;
 int             dropauth = 0;
-int             running = 1;
 int             reconfig = 0;
 u_long          num_received = 0;
 char            ddefault_port[] = "udp:162";	/* Default default port */
@@ -374,7 +375,7 @@ term_handler(int sig)
 #ifdef WIN32SERVICE
     extern netsnmp_session *main_session;
 #endif
-    running = 0;
+    netsnmp_running = 0;
 #ifdef WIN32SERVICE
     /*
      * In case of windows, select() in receive() function will not return 
@@ -1037,13 +1038,13 @@ main(int argc, char *argv[])
          * just starting up to process specific configuration and then
          * shutting down immediately. 
          */
-        running = 0;
+        netsnmp_running = 0;
     }
 #ifndef WIN32
     /*
      * fork the process to the background if we are not printing to stderr 
      */
-    if (dofork && running) {
+    if (dofork && netsnmp_running) {
         int             fd;
 
         switch (fork()) {
@@ -1178,7 +1179,7 @@ main(int argc, char *argv[])
 #ifdef WIN32SERVICE
     trapd_status = SNMPTRAPD_RUNNING;
 #endif
-    while (running) {
+    while (netsnmp_running) {
         if (reconfig) {
             if (Print || Log) {
                 struct tm      *tm;
@@ -1232,11 +1233,11 @@ main(int argc, char *argv[])
                 if (errno == EINTR)
                     continue;
                 snmp_log_perror("select");
-                running = 0;
+                netsnmp_running = 0;
                 break;
             default:
                 fprintf(stderr, "select returned %d\n", count);
-                running = 0;
+                netsnmp_running = 0;
             }
 	run_alarms();
     }
