@@ -150,7 +150,7 @@ extern          "C" {
                                                      *table_set,
                                                      char
                                                      *registration_name);
-    int netsnmp_table_set_num_rows(netsnmp_table_data_set *table);
+    int netsnmp_table_data_num_rows(netsnmp_table_data *table);
 
 #if HAVE_STDARG_H
     void           
