@@ -11,15 +11,18 @@ extern          "C" {
  */
 
 extern oid      usmNoAuthProtocol[10];  /* == { 1,3,6,1,6,3,10,1,1,1 }; */
+#ifndef DISABLE_MD5
 extern oid      usmHMACMD5AuthProtocol[10];     /* == { 1,3,6,1,6,3,10,1,1,2 }; */
+#endif
 extern oid      usmHMACSHA1AuthProtocol[10];    /* == { 1,3,6,1,6,3,10,1,1,3 }; */
 extern oid      usmNoPrivProtocol[10];  /* == { 1,3,6,1,6,3,10,1,2,1 }; */
+#ifndef DISABLE_DES
 extern oid      usmDESPrivProtocol[10]; /* == { 1,3,6,1,6,3,10,1,2,2 }; */
+#endif
 
 /* XXX: OIDs not defined yet */
-extern oid      usmAES128PrivProtocol[10]; /* == { 1,3,6,1,6,3,10,1,2,4 }; */
-extern oid      usmAES192PrivProtocol[10]; /* == { XXX, 1, 3 }; */
-extern oid      usmAES256PrivProtocol[10]; /* == { XXX, 1, 4 }; */
+extern oid      usmAESPrivProtocol[10]; /* == { 1,3,6,1,6,3,10,1,2,4 }; */
+extern oid      *usmAES128PrivProtocol; /* backwards compat */
 
 #define USM_AUTH_PROTO_NOAUTH_LEN 10
 #define USM_AUTH_PROTO_MD5_LEN 10
@@ -27,9 +30,8 @@ extern oid      usmAES256PrivProtocol[10]; /* == { XXX, 1, 4 }; */
 #define USM_PRIV_PROTO_NOPRIV_LEN 10
 #define USM_PRIV_PROTO_DES_LEN 10
 
-#define USM_PRIV_PROTO_AES128_LEN 10
-#define USM_PRIV_PROTO_AES192_LEN 10
-#define USM_PRIV_PROTO_AES256_LEN 10
+#define USM_PRIV_PROTO_AES_LEN 10
+#define USM_PRIV_PROTO_AES128_LEN 10 /* backwards compat */
 
 #ifdef __cplusplus
 }
