@@ -6,7 +6,10 @@
  * udp_inpcb list symbol 
  */
 #undef INP_NEXT_SYMBOL
-#define INP_NEXT_SYMBOL inp_next
+#define INP_NEXT_SYMBOL inp_list.le_next
+
+#undef INP_PREV_SYMBOL
+#define INP_PREV_SYMBOL inp_list.le_prev
 
 #undef TCP_TTL_SYMBOL
 #define TCP_TTL_SYMBOL "ip_defttl"
@@ -16,3 +19,5 @@
 #else
 #define UTMP_FILE "/var/run/utmp"
 #endif
+
+#define UDP_ADDRESSES_IN_HOST_ORDER 1
