@@ -20,45 +20,6 @@ mib_OidToTxt(oid * O, size_t OidLen, char *Buf, size_t BufLen)
 }
 
 
-
-char           *
-snmp_pdu_type(netsnmp_pdu *PDU)
-{
-    switch (PDU->command) {
-    case SNMP_MSG_GET:
-        return ("GET");
-        break;
-    case SNMP_MSG_GETNEXT:
-        return ("GETNEXT");
-        break;
-    case SNMP_MSG_RESPONSE:
-        return ("RESPONSE");
-        break;
-    case SNMP_MSG_SET:
-        return ("SET");
-        break;
-    case SNMP_MSG_GETBULK:
-        return ("GETBULK");
-        break;
-    case SNMP_MSG_INFORM:
-        return ("INFORM");
-        break;
-    case SNMP_MSG_TRAP2:
-        return ("V2TRAP");
-        break;
-    case SNMP_MSG_REPORT:
-        return ("REPORT");
-        break;
-
-    case SNMP_MSG_TRAP:
-        return ("V1TRAP");
-        break;
-    default:
-        return ("Unknown");
-        break;
-    }
-}
-
 /*
  * cmu_snmp_parse - emulate CMU library's snmp_parse.
  *
