@@ -172,7 +172,7 @@ register_app_prenetsnmp_mib_handler(const char *token,
  * management of where to put tokens as the module or modules get more complex
  * in regard to handling token registrations.
  *
- * @param type     the configuration file used, e.g., if snmp.conf is the file
+ * @param type_param the configuration file used, e.g., if snmp.conf is the file
  *                 where the token is located use "snmp" here.
  *                 If NULL the configuration file used will be snmpd.conf.
  *
@@ -611,8 +611,7 @@ netsnmp_config_remember_free_list(struct read_config_memory **mem)
         SNMP_FREE((*mem)->line);
         tmpmem = (*mem)->next;
         SNMP_FREE(*mem);
-        *mem = NULL;
-        mem = &tmpmem;
+        *mem = tmpmem;
     }
 }
 
@@ -1601,8 +1600,18 @@ read_config_read_octet_string(char *readfrom, u_char ** str, size_t * len)
             }
             *str = cptr;
         } else {
-            if (ilen >= *len)
-                ilen = *len-1;
+            /*
+             * don't require caller to have +1 for good measure, and 
+             * bail if not enough space.
+             */
+            if (ilen > *len) {
+                snmp_log(LOG_WARNING,"buffer too small to read octet string (%d < %d)\n",
+                         *len, ilen);
+                DEBUGMSGTL(("read_config_read_octet_string",
+                            "buffer too small (%d < %d)", *len, ilen));
+                cptr = skip_not_white(readfrom);
+                return skip_white(cptr);
+            }
             cptr = *str;
         }
         *len = ilen;
@@ -1729,7 +1738,7 @@ read_config_read_objid(char *readfrom, oid ** objid, size_t * len)
  *
  * @param type the asn data type to be read in.
  *
- * @param readform the configuration line data to be read.
+ * @param readfrom the configuration line data to be read.
  *
  * @param dataptr an allocated pointer expected to match the type being read
  *        (int *, u_int *, char **, oid **)
