@@ -165,7 +165,7 @@ netsnmp_tcp_accept(netsnmp_transport *t)
     struct sockaddr *farend = NULL;
     int             newsock = -1, sockflags = 0;
     socklen_t       farendlen = sizeof(struct sockaddr_in);
-    char           *string = NULL;
+    char           *str = NULL;
 
     farend = (struct sockaddr *) malloc(sizeof(struct sockaddr_in));
 
@@ -193,9 +193,9 @@ netsnmp_tcp_accept(netsnmp_transport *t)
 
         t->data = farend;
         t->data_length = farendlen;
-        string = netsnmp_tcp_fmtaddr(NULL, farend, farendlen);
-        DEBUGMSGTL(("netsnmp_tcp", "accept succeeded (from %s)\n", string));
-        free(string);
+        str = netsnmp_tcp_fmtaddr(NULL, farend, farendlen);
+        DEBUGMSGTL(("netsnmp_tcp", "accept succeeded (from %s)\n", str));
+        free(str);
 
         /*
          * Try to make the new socket blocking.  
@@ -392,11 +392,11 @@ netsnmp_tcp_transport(struct sockaddr_in *addr, int local)
 
 
 netsnmp_transport *
-netsnmp_tcp_create_tstring(const char *string, int local)
+netsnmp_tcp_create_tstring(const char *str, int local)
 {
     struct sockaddr_in addr;
 
-    if (netsnmp_sockaddr_in(&addr, string, 0)) {
+    if (netsnmp_sockaddr_in(&addr, str, 0)) {
         return netsnmp_tcp_transport(&addr, local);
     } else {
         return NULL;
