@@ -55,6 +55,8 @@
 
 #include <net-snmp/library/snmp_transport.h>
 #include <net-snmp/library/snmpUDPDomain.h>
+#include <net-snmp/library/system.h>
+#include <net-snmp/library/tools.h>
 
 #ifndef INADDR_NONE
 #define INADDR_NONE	-1
@@ -128,11 +130,11 @@ netsnmp_udp_recv(netsnmp_transport *t, void *buf, int size,
 	}
 
         if (rc >= 0) {
-            char *string = netsnmp_udp_fmtaddr(NULL, from, fromlen);
+            char *str = netsnmp_udp_fmtaddr(NULL, from, fromlen);
             DEBUGMSGTL(("netsnmp_udp",
 			"recvfrom fd %d got %d bytes (from %s)\n",
-			t->sock, rc, string));
-            free(string);
+			t->sock, rc, str));
+            free(str);
         } else {
             DEBUGMSGTL(("netsnmp_udp", "recvfrom fd %d err %d (\"%s\")\n",
                         t->sock, errno, strerror(errno)));
@@ -161,11 +163,11 @@ netsnmp_udp_send(netsnmp_transport *t, void *buf, int size,
     }
 
     if (to != NULL && t != NULL && t->sock >= 0) {
-        char *string = netsnmp_udp_fmtaddr(NULL, (void *) to,
+        char *str = netsnmp_udp_fmtaddr(NULL, (void *) to,
 					sizeof(struct sockaddr_in));
         DEBUGMSGTL(("netsnmp_udp", "send %d bytes from %p to %s on fd %d\n",
-                    size, buf, string, t->sock));
-        free(string);
+                    size, buf, str, t->sock));
+        free(str);
 	while (rc < 0) {
 	    rc = sendto(t->sock, buf, size, 0, to, sizeof(struct sockaddr));
 	    if (rc < 0 && errno != EINTR) {
@@ -480,7 +482,7 @@ netsnmp_udp_transport(struct sockaddr_in *addr, int local)
 {
     netsnmp_transport *t = NULL;
     int             rc = 0;
-    char           *string = NULL;
+    char           *str = NULL;
     char           *client_socket = NULL;
 
     if (addr == NULL || addr->sin_family != AF_INET) {
@@ -492,11 +494,11 @@ netsnmp_udp_transport(struct sockaddr_in *addr, int local)
         return NULL;
     }
 
-    string = netsnmp_udp_fmtaddr(NULL, (void *)addr, 
+    str = netsnmp_udp_fmtaddr(NULL, (void *)addr, 
 				 sizeof(struct sockaddr_in));
     DEBUGMSGTL(("netsnmp_udp", "open %s %s:%d\n", local ? "local" : "remote",
-                string,addr->sin_port));
-    free(string);
+                str,addr->sin_port));
+    free(str);
 
     memset(t, 0, sizeof(netsnmp_transport));
 
@@ -767,7 +769,7 @@ netsnmp_udp_parse_security(const char *token, char *param)
     char            secName[VACMSTRINGLEN];
     char            contextName[VACMSTRINGLEN];
     char            community[VACMSTRINGLEN];
-    char            source[VACMSTRINGLEN];
+    char            source[SNMP_MAXBUF_SMALL];
     char           *cp = NULL;
     const char     *strmask = NULL;
     com2SecEntry   *e = NULL;
@@ -1054,11 +1056,11 @@ netsnmp_udp_getSecName(void *opaque, int olength,
 
 
 netsnmp_transport *
-netsnmp_udp_create_tstring(const char *string, int local)
+netsnmp_udp_create_tstring(const char *str, int local)
 {
     struct sockaddr_in addr;
 
-    if (netsnmp_sockaddr_in(&addr, string, 0)) {
+    if (netsnmp_sockaddr_in(&addr, str, 0)) {
         return netsnmp_udp_transport(&addr, local);
     } else {
         return NULL;
