@@ -147,11 +147,11 @@ netsnmp_udp6_recv(netsnmp_transport *t, void *buf, int size,
 	}
 
         if (rc >= 0) {
-	    char *string = netsnmp_udp6_fmtaddr(NULL, from, fromlen);
+	    char *str = netsnmp_udp6_fmtaddr(NULL, from, fromlen);
             DEBUGMSGTL(("netsnmp_udp6",
 			"recvfrom fd %d got %d bytes (from %s)\n", t->sock,
-                        rc, string));
-            free(string);
+                        rc, str));
+            free(str);
         } else {
             DEBUGMSGTL(("netsnmp_udp6", "recvfrom fd %d err %d (\"%s\")\n",
 			t->sock, errno, strerror(errno)));
@@ -180,11 +180,11 @@ netsnmp_udp6_send(netsnmp_transport *t, void *buf, int size,
     }
 
     if (to != NULL && t != NULL && t->sock >= 0) {
-        char *string = netsnmp_udp6_fmtaddr(NULL, (void *)to,
+        char *str = netsnmp_udp6_fmtaddr(NULL, (void *)to,
 					    sizeof(struct sockaddr_in6));
         DEBUGMSGTL(("netsnmp_udp6", "send %d bytes from %p to %s on fd %d\n",
-                    size, buf, string, t->sock));
-        free(string);
+                    size, buf, str, t->sock));
+        free(str);
 	while (rc < 0) {
 	    rc = sendto(t->sock, buf, size, 0, to,sizeof(struct sockaddr_in6));
 	    if (rc < 0 && errno != EINTR) {
@@ -226,7 +226,7 @@ netsnmp_udp6_transport(struct sockaddr_in6 *addr, int local)
 {
     netsnmp_transport *t = NULL;
     int             rc = 0;
-    char           *string = NULL;
+    char           *str = NULL;
 
     if (addr == NULL || addr->sin6_family != AF_INET6) {
         return NULL;
@@ -237,11 +237,11 @@ netsnmp_udp6_transport(struct sockaddr_in6 *addr, int local)
         return NULL;
     }
 
-    string = netsnmp_udp6_fmtaddr(NULL, (void *) addr,
+    str = netsnmp_udp6_fmtaddr(NULL, (void *) addr,
 				  sizeof(struct sockaddr_in6));
     DEBUGMSGTL(("netsnmp_udp6", "open %s %s\n", local ? "local" : "remote",
-                string));
-    free(string);
+                str));
+    free(str);
 
     memset(t, 0, sizeof(netsnmp_transport));
 
@@ -765,6 +765,10 @@ inet_addrs_consistence(int pf, void *net, void *mask)
     switch (pf) {
     case PF_INET:
         tmp = (struct sockaddr_in *) malloc(sizeof(struct sockaddr_in));
+        if (!tmp) {
+            config_perror("Resource failure in inet_addr_consistence()");
+            return -1;
+        }
         memset(tmp, 0, sizeof(*tmp));
         tmp->sin_family = PF_INET;
         if (inet_addr_complement
@@ -774,6 +778,11 @@ inet_addrs_consistence(int pf, void *net, void *mask)
             return -1;
         }
         dst = (struct sockaddr_in *) malloc(sizeof(struct sockaddr_in));
+        if (!dst) {
+            config_perror("Resource failure in inet_addr_consistence()");
+            free(tmp);
+            return -1;
+        }
         memset(dst, 0, sizeof(*dst));
         dst->sin_family = PF_INET;
         if (inet_addr_and
@@ -790,6 +799,10 @@ inet_addrs_consistence(int pf, void *net, void *mask)
         break;
     case PF_INET6:
         tmp6 = (struct sockaddr_in6 *) malloc(sizeof(struct sockaddr_in6));
+        if (!tmp6) {
+            config_perror("Resource failure in inet_addr_consistence()");
+            return -1;
+        }
         memset(tmp6, 0, sizeof(*tmp6));
         tmp6->sin6_family = PF_INET6;
         if (inet_addr_complement
@@ -799,6 +812,11 @@ inet_addrs_consistence(int pf, void *net, void *mask)
             return -1;
         }
         dst6 = (struct sockaddr_in6 *) malloc(sizeof(struct sockaddr_in6));
+        if (!dst6) {
+            config_perror("Resource failure in inet_addr_consistence()");
+            free(tmp6);
+            return -1;
+        }
         memset(dst6, 0, sizeof(*dst6));
         dst6->sin6_family = PF_INET6;
         if (inet_addr_and
@@ -1271,11 +1289,11 @@ netsnmp_udp6_getSecName(void *opaque, int olength,
 #endif /* support for community based SNMP */
 
 netsnmp_transport *
-netsnmp_udp6_create_tstring(const char *string, int local)
+netsnmp_udp6_create_tstring(const char *str, int local)
 {
     struct sockaddr_in6 addr;
 
-    if (netsnmp_sockaddr_in6(&addr, string, 0)) {
+    if (netsnmp_sockaddr_in6(&addr, str, 0)) {
         return netsnmp_udp6_transport(&addr, local);
     } else {
         return NULL;
