@@ -33,6 +33,9 @@ SOFTWARE.
 #endif
 
 #include <stdio.h>
+#if HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
 #if HAVE_STRING_H
 #include <string.h>
 #else
