@@ -100,6 +100,7 @@ SOFTWARE.
 #include <net-snmp/library/snmp_secmod.h>
 #include <net-snmp/library/mib.h>
 #include <net-snmp/library/snmp_logging.h>
+#include <net-snmp/library/snmp_assert.h>
 
 
 #ifndef BSD4_3
@@ -173,7 +174,7 @@ snmp_synch_input(int op,
 
     state->waiting = 0;
 
-    if (op == NETSNMP_CALLBACK_OP_RECEIVED_MESSAGE) {
+    if (op == NETSNMP_CALLBACK_OP_RECEIVED_MESSAGE && pdu) {
         if (pdu->command == SNMP_MSG_REPORT) {
             rpt_type = snmpv3_get_report_type(pdu);
             if (SNMPV3_IGNORE_UNAUTH_REPORTS ||
@@ -732,9 +733,6 @@ snmp_set_var_value(netsnmp_variable_list * vars,
                    const u_char * value, size_t len)
 {
     int             largeval = 1;
-    const long     *val_long = NULL;
-    const int      *val_int  = NULL;
-    const u_int    *val_uint  = NULL;
 
     /*
      * xxx-rks: why the unconditional free? why not use existing
@@ -764,7 +762,6 @@ snmp_set_var_value(netsnmp_variable_list * vars,
     case ASN_INTEGER:
     case ASN_UNSIGNED:
     case ASN_TIMETICKS:
-    case ASN_IPADDRESS:
     case ASN_COUNTER:
         if (value) {
             if (vars->val_len == sizeof(int)) {
@@ -852,6 +849,11 @@ snmp_set_var_value(netsnmp_variable_list * vars,
         memmove(vars->val.objid, value, vars->val_len);
         break;
 
+    case ASN_IPADDRESS: /* snmp_build_var_op treats IPADDR like a string */
+        if (4 != vars->val_len) {
+            netsnmp_assert("ipaddress length == 4");
+        }
+        /** FALL THROUGH */
     case ASN_PRIV_IMPLIED_OCTET_STR:
     case ASN_OCTET_STR:
     case ASN_BIT_STR:
