@@ -357,7 +357,7 @@ debugmsg_oidrange(const char *token, const oid * theoid, size_t len,
         char            tmpbuf[128];
         /* XXX - ? check for 0 == var_subid -1 ? */
         rc = sprint_realloc_objid(&buf, &buf_len, &out_len, 1, theoid,
-                                  var_subid-1); /* Adjust for C's 0-based array indexing */
+                                  var_subid-1);  /* Adjust for C's 0-based array indexing */
         if (rc) {
             sprintf(tmpbuf, ".%lu--%lu", theoid[var_subid - 1],
                     range_ubound);
@@ -466,6 +466,33 @@ debugmsgtoken(va_alist)
     va_end(debugargs);
 }
 
+void
+#if HAVE_STDARG_H
+debug_combo_nc(const char *token, const char *format, ...)
+#else
+debugmsgtoken(va_alist)
+     va_dcl
+#endif
+{
+    va_list         debugargs;
+
+#if HAVE_STDARG_H
+    va_start(debugargs, format);
+#else
+    const char     *format;
+    const char     *token;
+
+    va_start(debugargs);
+    token = va_arg(debugargs, const char *);
+    format = va_arg(debugargs, const char *);   /* ??? */
+#endif
+
+    snmp_log(LOG_DEBUG, "%s: ", token);
+    snmp_vlog(LOG_DEBUG, format, debugargs);
+
+    va_end(debugargs);
+}
+
 /*
  * for speed, these shouldn't be in default_storage space 
  */
