@@ -137,6 +137,7 @@ vacm_parse_config_view(const char *token, char *line)
     line = skip_token(line);
     view.viewType = atoi(line);
     line = skip_token(line);
+    len = sizeof(view.viewName);
     line =
         read_config_read_octet_string(line, (u_char **) & viewName, &len);
     view.viewSubtreeLen = MAX_OID_LEN;
@@ -147,8 +148,9 @@ vacm_parse_config_view(const char *token, char *line)
     vptr =
         vacm_createViewEntry(view.viewName, view.viewSubtree,
                              view.viewSubtreeLen);
-    if (!vptr)
+    if (!vptr) {
         return;
+    }
 
     vptr->viewStatus = view.viewStatus;
     vptr->viewStorageType = view.viewStorageType;
@@ -221,8 +223,10 @@ vacm_parse_config_access(const char *token, char *line)
     line = skip_token(line);
     access.contextMatch = atoi(line);
     line = skip_token(line);
+    len = sizeof(access.groupName);
     line =
         read_config_read_octet_string(line, (u_char **) & groupName, &len);
+    len = sizeof(access.contextPrefix);
     line =
         read_config_read_octet_string(line, (u_char **) & contextPrefix,
                                       &len);
@@ -239,12 +243,15 @@ vacm_parse_config_access(const char *token, char *line)
     aptr->securityLevel = access.securityLevel;
     aptr->contextMatch = access.contextMatch;
     readView = (char *) aptr->readView;
+    len = sizeof(aptr->readView);
     line =
         read_config_read_octet_string(line, (u_char **) & readView, &len);
     writeView = (char *) aptr->writeView;
+    len = sizeof(aptr->writeView);
     line =
         read_config_read_octet_string(line, (u_char **) & writeView, &len);
     notifyView = (char *) aptr->notifyView;
+    len = sizeof(aptr->notifyView);
     line =
         read_config_read_octet_string(line, (u_char **) & notifyView,
                                       &len);
@@ -293,6 +300,7 @@ vacm_parse_config_group(const char *token, char *line)
     line = skip_token(line);
     group.securityModel = atoi(line);
     line = skip_token(line);
+    len = sizeof(group.securityName);
     line =
         read_config_read_octet_string(line, (u_char **) & securityName,
                                       &len);
@@ -304,6 +312,7 @@ vacm_parse_config_group(const char *token, char *line)
     gptr->status = group.status;
     gptr->storageType = group.storageType;
     groupName = (char *) gptr->groupName;
+    len = sizeof(group.groupName);
     line =
         read_config_read_octet_string(line, (u_char **) & groupName, &len);
 }
@@ -614,7 +623,7 @@ vacm_destroyViewEntry(const char *viewName,
                 break;
             lastvp = vp;
         }
-        if (!vp)
+        if (!vp || !lastvp)
             return;
         lastvp->next = vp->next;
     }
@@ -737,7 +746,7 @@ vacm_destroyGroupEntry(int securityModel, const char *securityName)
                 break;
             lastvp = vp;
         }
-        if (!vp)
+        if (!vp || !lastvp)
             return;
         lastvp->next = vp->next;
     }
@@ -900,7 +909,7 @@ vacm_destroyAccessEntry(const char *groupName,
                 break;
             lastvp = vp;
         }
-        if (!vp)
+        if (!vp || !lastvp)
             return;
         lastvp->next = vp->next;
     }
